module namespace sch-validation = "http://www.architextus.com/xquery/library/nutsh-sch-validation";
import module namespace schematron = "http://github.com/Schematron/schematron-basex";

declare namespace sch = "http://purl.oclc.org/dsdl/schematron";
declare namespace sqf = "http://www.schematron-quickfix.com/validator/process";


declare function sch-validation:validate-content-db($db as xs:string) {
   let $sch-rules := db:open('AppResources')/*[@id = 'authoring-sch']
   let $sch := schematron:compile($sch-rules)
   (: If node starts on assignation line, close at } at let position 
      and keep 1 level or indent in {} (currently, it doubles the indent distance) :)
   let $errors := <ul class="errors">{
      for $doc in db:open($db)/*
      let $validation := schematron:validate($doc, $sch)
      let $is-valid := schematron:is-valid($validation)
      return
         if ($is-valid)
         (: Offer option to keep as single line after then () or return () :)
         then ()
         else
            for $message in schematron:messages($validation)
            return <li>{
               concat(schematron:message-level($message), ': ', schematron:message-description($message))
            }</li>
   }</ul>
   return
      $errors
};

declare function sch-validation:validate-content-db-2($db as xs:string) {
   let $sch-rules := db:open('AppResources')/*[@id = 'authoring-sch']
   let $sch := schematron:compile($sch-rules)
   (: If node starts on new line, close the } at let position or the </ul> and </ul> position if no }
      and keep 1 level or indent in {} (currently, it doubles the indent distance) :)
   let $errors := 
      <ul class="errors">{
         for $doc in db:open($db)/*
         let $validation := schematron:validate($doc, $sch)
         let $is-valid := schematron:is-valid($validation)
         return
            if ($is-valid)
            (: Offer option to not force new line a new line after then and return :)
            then ()
            else
               for $message in schematron:messages($validation)
               return <li>{
                  concat(schematron:message-level($message), ': ', schematron:message-description($message))
               }</li>
      }</ul>
      
   (: In complex situations indenting all the else if just creates a mess, don't indent else ifs, 
       or offer to set option not to indent :)
   let $lots-of-let-expressions := 
      if (1=2)
      then 'You are crazy'
      else if (1=3)
      then 'I really can''t get over this'
      else if (1=4)
      then 'I really can''t get over this either'
      else if (1=5)
      then 'You can''t be serious'
      else if (1=6)
      then 'So indented I must cry'
      else if (1=7)
      then 'So indented I must cry'
      else if (1=8)
      then 'So indented I must cry'
      else if (1=9)
      then 'So indented I must cry'
      else if (1=10)
      then 'So indented I must cry'
      else if (1=1)
      then 'Yé'
      else 'Hmmm, whatever, you are sooooooo wrong!'
   (: Indent the 1st level under let because when there are many complex let statements
      it becomes hard to see where each starts and ends, it just looks like one big let
      especially when let is complex and contains other let statements
      Let $test and let $final should not be aligned with let $even-more-expression:)
   let $more-expressions := 
      for $i in db:open($db)//*[@id]
      let $temp := 'b'
      let $final := 
         let $test := 
            if ($i = $temp)
            then 'yep'
            else 'nope'
         return $test
      return $final
   let $even-more-expressions := 
      if (1=2)
      then 'You are crazy'
      else if (1=3)
      then 'I really can''t get over this'
      else if (1=4)
      then 'I really can''t get over this either'
      else if (1=5)
      then 'You can''t be serious'
      else if (1=1)
      then 'Yé'
      else 'Hmmm, whatever, you are sooooooo wrong!'
   let $other-stuff-that-may-be-long := 
      switch ($db)
      case 'en-us' return 'blue'
      case 'es-us' return 'orange'
      default return 'white'
      (: Offer option to not force new line a new line after then and return :)
   return 'Whatever'
};

